==> RWebServices_1.6.0.tar.gz: RWebServices/inst/rservices/src/org/bioconductor/packages/rservices/RServicesEnv.java <==
package org.bioconductor.packages.rservices;

import org.omegahat.R.Java.ROmegahatInterpreter;
import org.omegahat.R.Java.REvaluator;
import java.net.URL;

public class RServicesEnv {
	protected REvaluator e;

	protected RServicesEnv() throws Exception {
		ROmegahatInterpreter interp = new ROmegahatInterpreter(
				ROmegahatInterpreter.fixArgs(new String[] { "--quiet",
						"--vanilla" }), false);
		e = new REvaluator();
		e.voidEval("library(RWebServices)");
	}

	public Object call(String funcName, Object[] inputs) throws Exception {
		return e.call(funcName, inputs);
	}

	public void source(String scriptName) throws Exception {
		e.voidEval("source('" + scriptName + "')");
	}

	public void importCvt(String rPackageName) throws Exception {
		URL cvtUrl = getClass().getResource("R/" + rPackageName + ".R");
		if (null != cvtUrl) {
			// allow for packages without special converters
			String cvtFile = cvtUrl.getFile();
			e.voidEval("source(\"" + cvtFile + "\")");
		}
	}

	public void rm(String rVariable) throws Exception {
		e.voidEval("rm(\"" + rVariable + "\")");
	}

	public void setDataLoaderEnv() throws Exception {
		e.voidEval("rwebservices_dataloader_env <- new.env(parent=emptyenv())");
	}

	public void rmDataLoaderEnv() throws Exception {
		e.voidEval("rm(rwebservices_dataloader_env)");
	}

	public Object loadRData(String rdaFileName) throws Exception {
		String le = "rwebservices_dataloader_env";
		e.voidEval("rm(list=ls(envir=" + le + "), envir=" + le + ")");
		e.voidEval("load(\"" + rdaFileName + "\", envir=" + le + ")");
		e.voidEval("if(length(ls(envir=" + le
				+ "))!=1) stop('number of objects being load is not 1')");
		Object res = e
				.eval("get(ls(envir=" + le + "), envir=" + le + ")", true);
		return res;
	}

	public Object dataRData(String rdaFileName) throws Exception {
		String le = "rwebservices_dataloader_env";
		e.voidEval("rm(list=ls(envir=" + le + "), envir=" + le + ")");
		e.voidEval("data(\"" + rdaFileName + "\", envir=" + le + ")");
		e.voidEval("if(length(ls(envir=" + le
				+ "))!=1) stop('number of objects being load is not 1')");
		Object res = e
				.eval("get(ls(envir=" + le + "), envir=" + le + ")", true);
		return res;
	}

}

==> RWebServices_1.26.0.tar.gz: RWebServices/inst/rservices/src/org/bioconductor/packages/rservices/RServicesEnv.java <==
package org.bioconductor.packages.rservices;

import org.omegahat.R.Java.ROmegahatInterpreter;
import org.omegahat.R.Java.REvaluator;
import java.net.URL;

public class RServicesEnv {
	protected REvaluator e;

	protected RServicesEnv() throws Exception {
		ROmegahatInterpreter interp = new ROmegahatInterpreter(
				ROmegahatInterpreter.fixArgs(new String[] { "--quiet",
						"--vanilla" }), false);
		e = new REvaluator();
		e.voidEval("library(RWebServices)");
	}

	public Object call(String funcName, Object[] inputs) throws Exception {
		return e.call(funcName, inputs);
	}

	public void source(String scriptName) throws Exception {
		e.voidEval("source('" + scriptName + "')");
	}

	public void importCvt(String rPackageName) throws Exception {
		URL cvtUrl = getClass().getResource("R/" + rPackageName + ".R");
		if (null != cvtUrl) {
			// allow for packages without special converters
			String cvtFile = cvtUrl.getFile();
			e.voidEval("source(\"" + cvtFile + "\")");
		}
	}

	public void rm(String rVariable) throws Exception {
		e.voidEval("rm(\"" + rVariable + "\")");
	}

	public void setDataLoaderEnv() throws Exception {
		e.voidEval("rwebservices_dataloader_env <- new.env(parent=emptyenv())");
	}

	public void rmDataLoaderEnv() throws Exception {
		e.voidEval("rm(rwebservices_dataloader_env)");
	}

	public Object loadRData(String rdaFileName) throws Exception {
		String le = "rwebservices_dataloader_env";
		e.voidEval("rm(list=ls(envir=" + le + "), envir=" + le + ")");
		e.voidEval("load(\"" + rdaFileName + "\", envir=" + le + ")");
		e.voidEval("if(length(ls(envir=" + le
				+ "))!=1) stop('number of objects being loaded is not 1')");
		Object res = e
				.eval("get(ls(envir=" + le + "), envir=" + le + ")", true);
		return res;
	}

	public Object dataRData(String rdaFileName) throws Exception {
		String le = "rwebservices_dataloader_env";
		e.voidEval("rm(list=ls(envir=" + le + "), envir=" + le + ")");
		e.voidEval("data(\"" + rdaFileName + "\", envir=" + le + ")");
		e.voidEval("if(length(ls(envir=" + le
				+ "))!=1) stop('number of objects being loaded is not 1')");
		Object res = e
				.eval("get(ls(envir=" + le + "), envir=" + le + ")", true);
		return res;
	}

}
